SchemaSpy - gnss_data.public

Tables Relationships Utility Tables Constraints Anomalies Columns Donate

SchemaSpy Analysis of gnss_data.public | Generated by SchemaSpy

Generated by SchemaSpy on Fri Jul 28 14:55 EDT 2017
Database Type: PostgreSQL - 9.6.1 |
XML Representation Insertion Order Deletion Order (for database loading/purging scripts)

Comments

Table | Children | Parents | Columns | Rows | Comments
--- | --- | --- | --- | --- | ---
antennas | 1 |  | 2 | 71 |
apr_coords |  | 2 | 12 | 0 |
earthquakes |  |  | 5 | 3,263 |
events |  |  | 4 | 632,745 |
gamit_soln |  | 6 | 16 | 62,345 |
keys | 1 |  | 5 | 7 |
locks |  | 2 | 3 | 63 |
networks | 1 |  | 2 | 21 |
ppp_soln |  | 6 | 14 | 685,567 |
ppp_soln_excl |  | 2 | 4 | 1 |
receivers | 1 |  | 2 | 68 |
rinex | 8 | 2 | 18 | 726,860 |
rinex_extra |  | 2 | 18 | 13,308 |
rinex_tank_struct |  | 1 | 2 | 3 |
stationinfo |  | 4 | 15 | 998 |
stations | 16 | 1 | 12 | 350 |
16 Tables |  |  | 134 | 2,125,670 |
0 Views |  |  | 0 |  |